.. _contributor_list:

**************************
Package contributors
**************************

Corrfunc project coordinator
===============================

* Manodeep Sinha

Lead developers
==========================

* Manodeep Sinha

Core package contributors
==========================

* Manodeep Sinha (@manodeep)
* Lehman Garrison (@lgarrison)
* Nick Hand (@nickhand)

Other credits
=============

* Corrfunc contains code from `Agner Fog <https://agner.org>`_, `GeometricTools
  <http://www.geometrictools.com/>`_, and the package `SGLIB
  <http://sglib.sourceforge.net/>`_. The LICENSE for these external files
  remains with the original author of the package.

* The entirety of the docs for Corrfunc is derived from `halotools
  <https://github.com/astropy/halotools>`_. I know, first-hand, how much of an
  effort it was for the developers of `halotools` to generate all of this
  documentation. Having such a template made creating the docs for Corrfunc a
  lot easier process.

* The API generation script for Corrfunc was lifted directly out of the
  repo `bccp/nbodykit/ <https://github.com/bccp/nbodykit/>`_.
